"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupAppFactory = void 0;
const child_process_1 = require("child_process");
const manifest_creation_1 = require("../manifest-creation");
const logging_middleware_1 = require("../server/logging-middleware");
exports.setupAppFactory = (host, port) => async function setupApp(app) {
    const setup = new manifest_creation_1.ManifestCreation();
    // If not on Glitch or Production, create a smee URL
    if (process.env.NODE_ENV !== "production" &&
        !(process.env.PROJECT_DOMAIN || process.env.WEBHOOK_PROXY_URL)) {
        await setup.createWebhookChannel();
    }
    const route = app.route();
    route.use(logging_middleware_1.getLoggingMiddleware(app.log));
    printWelcomeMessage(app, host, port);
    route.get("/probot", async (req, res) => {
        const protocols = req.headers["x-forwarded-proto"] || req.protocol;
        const protocol = typeof protocols === "string" ? protocols.split(",")[0] : protocols[0];
        const host = req.headers["x-forwarded-host"] || req.get("host");
        const baseUrl = `${protocol}://${host}`;
        const pkg = setup.pkg;
        const manifest = setup.getManifest(pkg, baseUrl);
        const createAppUrl = setup.createAppUrl;
        // Pass the manifest to be POST'd
        res.render("setup.hbs", { pkg, createAppUrl, manifest });
    });
    route.get("/probot/setup", async (req, res) => {
        const { code } = req.query;
        const response = await setup.createAppFromCode(code);
        // If using glitch, restart the app
        if (process.env.PROJECT_DOMAIN) {
            child_process_1.exec("refresh", (error) => {
                if (error) {
                    app.log.error(error);
                }
            });
        }
        res.redirect(`${response}/installations/new`);
    });
    route.get("/probot/success", async (req, res) => {
        res.render("success.hbs");
    });
    route.get("/", (req, res, next) => res.redirect("/probot"));
};
function printWelcomeMessage(app, host, port) {
    // use glitch env to get correct domain welcome message
    // https://glitch.com/help/project/
    const domain = process.env.PROJECT_DOMAIN ||
        `http://${host !== null && host !== void 0 ? host : "localhost"}:${port || 3000}`;
    [
        ``,
        `Welcome to Probot!`,
        `Probot is in setup mode, webhooks cannot be received and`,
        `custom routes will not work until APP_ID and PRIVATE_KEY`,
        `are configured in .env.`,
        `Please follow the instructions at ${domain} to configure .env.`,
        `Once you are done, restart the server.`,
        ``,
    ].forEach((line) => {
        app.log.info(line);
    });
}
//# sourceMappingURL=setup.js.map